==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Complete/Gui/Resources/translations/Complete_no.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Fullført</translation>
    </message>
    <message>
      <source>Constraint Axle...</source>
      <translation>Aksellås...</translation>
    </message>
    <message>
      <source>set a axle constraint between two objects</source>
      <translation>angi en akselbetingelse mellom to objekter</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Selvtest...</translation>
    </message>
    <message>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Kjører en selvtest for å kontrollere om programmet fungerer riktig</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Dr&amp;awing</source>
      <translation>T&amp;egning</translation>
    </message>
    <message>
      <source>S&amp;ketch</source>
      <translation>K&amp;ladd</translation>
    </message>
    <message>
      <source>&amp;Raytracing</source>
      <translation>&amp;Strålesporing</translation>
    </message>
    <message>
      <source>&amp;Drafting</source>
      <translation>&amp;Skissering</translation>
    </message>
    <message>
      <source>Sketch based</source>
      <translation>Skissebasert</translation>
    </message>
    <message>
      <source>Primitives</source>
      <translation>Primitiver</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation>Parametrisk</translation>
    </message>
    <message>
      <source>Object appearence</source>
      <translation>Objektetutseende</translation>
    </message>
    <message>
      <source>Wire Tools</source>
      <translation>Wire Tools</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Complete/Gui/Resources/translations/Complete_no.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="no" sourcelanguage="en">
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Fullført</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Constraint Axle...</source>
      <translation>Aksellås...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set a axle constraint between two objects</source>
      <translation>angi en akselbetingelse mellom to objekter</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Selvtest...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Kjører en selvtest for å kontrollere om programmet fungerer riktig</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location line="-9"/>
      <source>Dr&amp;awing</source>
      <translation>T&amp;egning</translation>
    </message>
    <message>
      <location line="-1"/>
      <source>S&amp;ketch</source>
      <translation>K&amp;ladd</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>&amp;Raytracing</source>
      <translation>&amp;Strålesporing</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Drafting</source>
      <translation>&amp;Skissering</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Sketch based</source>
      <translation>Skissebasert</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Primitives</source>
      <translation>Primitiver</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation type="obsolete">Parametrisk</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Object appearence</source>
      <translation>Objektutseende</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Wire Tools</source>
      <translation>Lenkeverktøy</translation>
    </message>
  </context>
</TS>
